@@ -2,6 +2,13 @@
 
 from .check import check_command
 from .format import format_code, format_code_legacy
+from .init import init_command
 from .list_tools import list_tools
 
-__all__ = ["check_command", "format_code", "format_code_legacy", "list_tools"]
+__all__ = [
+    "check_command",
+    "format_code",
+    "format_code_legacy",
+    "init_command",
+    "list_tools",
+]
