@@ -6,6 +6,8 @@ from enum import StrEnum, auto
 
 
 class DarglintStrictness(StrEnum):
+    """Strictness levels recognized by Darglint checks."""
+
     SHORT = auto()
     LONG = auto()
     FULL = auto()
@@ -14,6 +16,14 @@ class DarglintStrictness(StrEnum):
 def normalize_darglint_strictness(
     value: str | DarglintStrictness,
 ) -> DarglintStrictness:
+    """Normalize a strictness value, defaulting to FULL on error.
+
+    Args:
+        value: String or enum member representing strictness.
+
+    Returns:
+        DarglintStrictness: Normalized strictness enum value.
+    """
     if isinstance(value, DarglintStrictness):
         return value
     try:
