@@ -12,7 +12,9 @@ class ToolName(StrEnum):
     """Supported tool identifiers in lower-case values."""
 
     DARGLINT = auto()
+    ESLINT = auto()
     HADOLINT = auto()
+    MARKDOWNLINT = auto()
     PRETTIER = auto()
     RUFF = auto()
     YAMLLINT = auto()
