@@ -6,6 +6,8 @@ from enum import StrEnum, auto
 
 
 class YamllintFormat(StrEnum):
+    """Output styles supported by Yamllint's CLI."""
+
     PARSABLE = auto()
     STANDARD = auto()
     COLORED = auto()
@@ -14,6 +16,15 @@ class YamllintFormat(StrEnum):
 
 
 def normalize_yamllint_format(value: str | YamllintFormat) -> YamllintFormat:
+    """Normalize a value to a YamllintFormat enum member.
+
+    Args:
+        value: Existing enum member or string name of the format.
+
+    Returns:
+        YamllintFormat: Canonical enum value, defaulting to ``PARSABLE`` when
+        parsing fails.
+    """
     if isinstance(value, YamllintFormat):
         return value
     try:
