@@ -1,8 +1,16 @@
+"""Interfaces for describing table columns and rows for tool issues."""
+
 from abc import ABC, abstractmethod
 from typing import Any
 
 
 class TableDescriptor(ABC):
+    """Describe how to extract tabular data for a tool's issues.
+
+    Concrete implementations define column ordering and how to map issue
+    objects into a list of column values.
+    """
+
     @abstractmethod
     def get_columns(self) -> list[str]:
         """Return the list of column names in order."""
