@@ -12,10 +12,18 @@ from lintro.formatters.tools.darglint_formatter import (
     DarglintTableDescriptor,
     format_darglint_issues,
 )
+from lintro.formatters.tools.eslint_formatter import (
+    EslintTableDescriptor,
+    format_eslint_issues,
+)
 from lintro.formatters.tools.hadolint_formatter import (
     HadolintTableDescriptor,
     format_hadolint_issues,
 )
+from lintro.formatters.tools.markdownlint_formatter import (
+    MarkdownlintTableDescriptor,
+    format_markdownlint_issues,
+)
 from lintro.formatters.tools.prettier_formatter import (
     PrettierTableDescriptor,
     format_prettier_issues,
@@ -36,8 +44,12 @@ __all__ = [
     "format_bandit_issues",
     "DarglintTableDescriptor",
     "format_darglint_issues",
+    "EslintTableDescriptor",
+    "format_eslint_issues",
     "HadolintTableDescriptor",
     "format_hadolint_issues",
+    "MarkdownlintTableDescriptor",
+    "format_markdownlint_issues",
     "PrettierTableDescriptor",
     "format_prettier_issues",
     "RuffTableDescriptor",
