@@ -10,6 +10,7 @@ from lintro.tools.implementations.tool_black import BlackTool
 from lintro.tools.implementations.tool_darglint import DarglintTool
 from lintro.tools.implementations.tool_hadolint import HadolintTool
 from lintro.tools.implementations.tool_prettier import PrettierTool
+from lintro.tools.implementations.tool_pytest import PytestTool
 from lintro.tools.implementations.tool_ruff import RuffTool
 from lintro.tools.implementations.tool_yamllint import YamllintTool
 from lintro.tools.tool_enum import ToolEnum
@@ -21,7 +22,7 @@ tool_manager = ToolManager()
 AVAILABLE_TOOLS = {tool_enum: tool_enum.value for tool_enum in ToolEnum}
 
 
-for tool_enum, tool_class in AVAILABLE_TOOLS.items():
+for _tool_enum, tool_class in AVAILABLE_TOOLS.items():
     tool_manager.register_tool(tool_class)
 
 # Consolidated exports
@@ -39,6 +40,7 @@ __all__ = [
     "DarglintTool",
     "HadolintTool",
     "PrettierTool",
+    "PytestTool",
     "RuffTool",
     "YamllintTool",
 ]
