@@ -1,5 +1,6 @@
 """Integration tests for Ruff tool."""
 
+import contextlib
 import os
 import shutil
 import tempfile
@@ -16,19 +17,18 @@ logger.add(lambda msg: print(msg, end=""), level="INFO")
 
 
 @pytest.fixture(autouse=True)
-def set_lintro_test_mode_env():
-    """Set LINTRO_TEST_MODE=1 for all tests in this module.
+def set_lintro_test_mode_env(lintro_test_mode):
+    """Set LINTRO_TEST_MODE=1 and disable config injection for all tests.
+
+    Uses the shared lintro_test_mode fixture from conftest.py.
+
+    Args:
+        lintro_test_mode: Shared fixture that manages env vars.
 
     Yields:
         None: This fixture is used for its side effect only.
     """
-    old = os.environ.get("LINTRO_TEST_MODE")
-    os.environ["LINTRO_TEST_MODE"] = "1"
     yield
-    if old is not None:
-        os.environ["LINTRO_TEST_MODE"] = old
-    else:
-        del os.environ["LINTRO_TEST_MODE"]
 
 
 @pytest.fixture
@@ -91,15 +91,13 @@ def temp_python_file(request):
         f.flush()
         file_path = f.name
     print(f"[DEBUG] temp_python_file path: {file_path}")
-    with open(file_path, "r") as debug_f:
+    with open(file_path) as debug_f:
         print("[DEBUG] temp_python_file contents:")
         print(debug_f.read())
 
-    def cleanup():
-        try:
+    def cleanup() -> None:
+        with contextlib.suppress(FileNotFoundError):
             os.unlink(file_path)
-        except FileNotFoundError:
-            pass
 
     request.addfinalizer(cleanup)
     yield file_path
@@ -108,7 +106,7 @@ def temp_python_file(request):
 class TestRuffTool:
     """Test cases for RuffTool."""
 
-    def test_tool_initialization(self, ruff_tool):
+    def test_tool_initialization(self, ruff_tool) -> None:
         """Test that RuffTool initializes correctly.
 
         Args:
@@ -119,7 +117,7 @@ class TestRuffTool:
         assert_that(ruff_tool.config.file_patterns).contains("*.py")
         assert_that(ruff_tool.config.file_patterns).contains("*.pyi")
 
-    def test_tool_priority(self, ruff_tool):
+    def test_tool_priority(self, ruff_tool) -> None:
         """Test that RuffTool has high priority.
 
         Args:
@@ -127,7 +125,7 @@ class TestRuffTool:
         """
         assert_that(ruff_tool.config.priority).is_equal_to(85)
 
-    def test_lint_check_clean_file(self, ruff_tool, ruff_clean_file):
+    def test_lint_check_clean_file(self, ruff_tool, ruff_clean_file) -> None:
         """Test Ruff lint check on a clean file.
 
         Args:
@@ -141,7 +139,7 @@ class TestRuffTool:
         assert_that(result.success is True).is_true()
         assert_that(result.issues_count).is_equal_to(0)
 
-    def test_lint_check_violations(self, ruff_tool, ruff_violation_file):
+    def test_lint_check_violations(self, ruff_tool, ruff_violation_file) -> None:
         """Test Ruff lint check on a file with violations.
 
         Args:
@@ -155,7 +153,7 @@ class TestRuffTool:
         assert_that(result.success is False).is_true()
         assert_that(result.issues_count > 0).is_true()
 
-    def test_check_nonexistent_file(self, ruff_tool):
+    def test_check_nonexistent_file(self, ruff_tool) -> None:
         """Test checking a nonexistent file.
 
         Args:
@@ -164,7 +162,7 @@ class TestRuffTool:
         with pytest.raises(FileNotFoundError):
             ruff_tool.check(["/nonexistent/file.py"])
 
-    def test_check_empty_paths(self, ruff_tool):
+    def test_check_empty_paths(self, ruff_tool) -> None:
         """Test checking with empty paths.
 
         Args:
@@ -176,7 +174,7 @@ class TestRuffTool:
         assert_that(result.output).is_equal_to("No files to check.")
         assert_that(result.issues_count).is_equal_to(0)
 
-    def test_fix_with_violations(self, ruff_tool, temp_python_file):
+    def test_fix_with_violations(self, ruff_tool, temp_python_file) -> None:
         """Test fixing a file with violations.
 
         Args:
@@ -188,7 +186,7 @@ class TestRuffTool:
         assert_that(result.name).is_equal_to("ruff")
         assert_that(result.output).is_not_equal_to("No fixes applied.")
 
-    def test_set_options_valid(self, ruff_tool):
+    def test_set_options_valid(self, ruff_tool) -> None:
         """Test setting valid options.
 
         Args:
@@ -209,16 +207,16 @@ class TestRuffTool:
         assert_that(ruff_tool.options["unsafe_fixes"] is True).is_true()
         assert_that(ruff_tool.options["format"] is False).is_true()
 
-    def test_set_options_invalid_select(self, ruff_tool):
+    def test_set_options_invalid_select(self, ruff_tool) -> None:
         """Test setting invalid select option.
 
         Args:
             ruff_tool: RuffTool fixture instance.
         """
-        with pytest.raises(ValueError, match="select must be a list"):
-            ruff_tool.set_options(select="E,F")
+        with pytest.raises(ValueError, match="select must be a string or list"):
+            ruff_tool.set_options(select=123)
 
-    def test_set_options_invalid_line_length(self, ruff_tool):
+    def test_set_options_invalid_line_length(self, ruff_tool) -> None:
         """Test setting invalid line length.
 
         Args:
@@ -229,7 +227,7 @@ class TestRuffTool:
         with pytest.raises(ValueError, match="line_length must be positive"):
             ruff_tool.set_options(line_length=-1)
 
-    def test_build_check_command_basic(self, ruff_tool):
+    def test_build_check_command_basic(self, ruff_tool) -> None:
         """Test building basic check command.
 
         Args:
@@ -237,13 +235,15 @@ class TestRuffTool:
         """
         files = ["test.py"]
         cmd = ruff_tool._build_check_command(files)
-        assert_that(cmd[0]).is_equal_to("ruff")
-        assert_that(cmd[1]).is_equal_to("check")
+        # Ruff is run via python -m ruff, so cmd[0] is python exe,
+        # cmd[1] is "-m", cmd[2] is "ruff"
+        assert_that(cmd).contains("ruff")
+        assert_that(cmd).contains("check")
         assert_that(cmd).contains("--output-format")
         assert_that(cmd).contains("json")
         assert_that(cmd).contains("test.py")
 
-    def test_build_check_command_with_fix(self, ruff_tool):
+    def test_build_check_command_with_fix(self, ruff_tool) -> None:
         """Test building check command with fix option.
 
         Args:
@@ -253,7 +253,7 @@ class TestRuffTool:
         cmd = ruff_tool._build_check_command(files, fix=True)
         assert_that(cmd).contains("--fix")
 
-    def test_build_check_command_with_options(self, ruff_tool):
+    def test_build_check_command_with_options(self, ruff_tool) -> None:
         """Test building check command with various options.
 
         Args:
@@ -269,7 +269,7 @@ class TestRuffTool:
         assert_that(cmd).contains("--line-length")
         assert_that(cmd).contains("88")
 
-    def test_build_format_command_basic(self, ruff_tool):
+    def test_build_format_command_basic(self, ruff_tool) -> None:
         """Test building basic format command.
 
         Args:
@@ -277,11 +277,13 @@ class TestRuffTool:
         """
         files = ["test.py"]
         cmd = ruff_tool._build_format_command(files)
-        assert_that(cmd[0]).is_equal_to("ruff")
-        assert_that(cmd[1]).is_equal_to("format")
+        # Ruff is run via python -m ruff, so cmd[0] is python exe,
+        # cmd[1] is "-m", cmd[2] is "ruff"
+        assert_that(cmd).contains("ruff")
+        assert_that(cmd).contains("format")
         assert_that(cmd).contains("test.py")
 
-    def test_build_format_command_check_only(self, ruff_tool):
+    def test_build_format_command_check_only(self, ruff_tool) -> None:
         """Test building format command in check-only mode.
 
         Args:
@@ -291,7 +293,7 @@ class TestRuffTool:
         cmd = ruff_tool._build_format_command(files, check_only=True)
         assert_that(cmd).contains("--check")
 
-    def test_check_reports_formatting_issues(self, ruff_tool, request):
+    def test_check_reports_formatting_issues(self, ruff_tool, request) -> None:
         """Test that check reports formatting issues (not just lint issues).
 
         Args:
@@ -304,11 +306,9 @@ class TestRuffTool:
             f.flush()
             file_path = f.name
 
-        def cleanup():
-            try:
+        def cleanup() -> None:
+            with contextlib.suppress(FileNotFoundError):
                 os.unlink(file_path)
-            except FileNotFoundError:
-                pass
 
         request.addfinalizer(cleanup)
         ruff_tool.set_options(select=["E", "F"])
@@ -334,7 +334,7 @@ class TestRuffTool:
             ),
         ).is_true()
 
-    def test_format_check_clean_file(self, ruff_tool, ruff_clean_file):
+    def test_format_check_clean_file(self, ruff_tool, ruff_clean_file) -> None:
         """Test format check on a clean file.
 
         Args:
@@ -346,7 +346,7 @@ class TestRuffTool:
         assert_that(result.success is True).is_true()
         assert_that(result.issues_count).is_equal_to(0)
 
-    def test_format_check_violations(self, ruff_tool, ruff_violation_file):
+    def test_format_check_violations(self, ruff_tool, ruff_violation_file) -> None:
         """Test format check on a file with violations.
 
         Args:
@@ -359,9 +359,8 @@ class TestRuffTool:
         assert_that(result.issues_count > 0).is_true()
         assert_that(result.issues and len(result.issues) > 0).is_true()
 
-    def test_fmt_fixes_violations(self, ruff_tool, ruff_violation_file):
-        """
-        Test that applying format/fix to a file with violations improves the file.
+    def test_fmt_fixes_violations(self, ruff_tool, ruff_violation_file) -> None:
+        """Apply fix to a file and expect fewer or equal issues after.
 
         Args:
             ruff_tool: RuffTool fixture instance.
@@ -378,7 +377,10 @@ class TestRuffTool:
             f"{check_result.issues_count} (was {initial_issues})"
         )
 
-    def test_ruff_output_consistency_direct_vs_lintro(self, ruff_violation_file):
+    def test_ruff_output_consistency_direct_vs_lintro(
+        self,
+        ruff_violation_file,
+    ) -> None:
         """Ruff CLI vs Lintro: Should produce consistent results for the same file.
 
         Args:
@@ -409,7 +411,7 @@ class TestRuffTool:
                         line
                         for line in result.stdout.splitlines()
                         if ":" in line
-                        and any((code in line for code in ["E", "F", "I", "W"]))
+                        and any(code in line for code in ["E", "F", "I", "W"])
                     ],
                 )
         lintro_result = tool.check([ruff_violation_file])
@@ -425,8 +427,8 @@ class TestRuffTool:
             else 0
         )
         logger.info(
-            "[LOG] CLI issues: %s, Lintro lint issues: %s"
-            % (direct_issues, lintro_lint_issues),
+            f"[LOG] CLI issues: {direct_issues}, "
+            f"Lintro lint issues: {lintro_lint_issues}",
         )
         assert direct_issues == lintro_lint_issues, (
             "Issue count mismatch: "
@@ -435,3 +437,134 @@ class TestRuffTool:
             f"CLI Output:\n{result.stdout}\n"
             f"Lintro Output:\n{lintro_result.output}"
         )
+
+    def test_c4_comprehensions_rules(self, ruff_tool) -> None:
+        """Test C4 (flake8-comprehensions) rule detection.
+
+        Args:
+            ruff_tool: RuffTool fixture instance.
+        """
+        ruff_tool.set_options(select=["C4"])
+        result = ruff_tool.check(["test_samples/ruff_c4_comprehensions_violations.py"])
+        assert_that(isinstance(result, ToolResult)).is_true()
+        assert_that(result.name).is_equal_to("ruff")
+        assert_that(result.success is False).is_true()
+        assert_that(result.issues_count > 0).is_true()
+
+        # Check that C4 rules are detected
+        c4_issues = [
+            issue
+            for issue in result.issues
+            if hasattr(issue, "code") and issue.code.startswith("C4")
+        ]
+        assert_that(len(c4_issues)).is_greater_than(0)
+
+    def test_sim_simplify_rules(self, ruff_tool) -> None:
+        """Test SIM (flake8-simplify) rule detection.
+
+        Args:
+            ruff_tool: RuffTool fixture instance.
+        """
+        ruff_tool.set_options(select=["SIM"])
+        result = ruff_tool.check(["test_samples/ruff_sim_simplify_violations.py"])
+        assert_that(isinstance(result, ToolResult)).is_true()
+        assert_that(result.name).is_equal_to("ruff")
+        assert_that(result.success is False).is_true()
+        assert_that(result.issues_count > 0).is_true()
+
+        # Check that SIM rules are detected
+        sim_issues = [
+            issue
+            for issue in result.issues
+            if hasattr(issue, "code") and issue.code.startswith("SIM")
+        ]
+        assert_that(len(sim_issues)).is_greater_than(0)
+
+    def test_c4_comprehensions_fixing(self, ruff_tool) -> None:
+        """Test C4 (flake8-comprehensions) rule fixing.
+
+        Args:
+            ruff_tool: RuffTool fixture instance.
+        """
+        import os
+        import tempfile
+
+        # Create a temporary file with C4 violations
+        content = """
+def test_function():
+    numbers = [1, 2, 3, 4, 5]
+    # C401: Unnecessary list comprehension
+    result = [x for x in numbers]
+    return result
+"""
+
+        with tempfile.NamedTemporaryFile(mode="w", suffix=".py", delete=False) as f:
+            f.write(content)
+            f.flush()
+            temp_file = f.name
+
+        try:
+            # Check initial issues
+            ruff_tool.set_options(select=["C4"], unsafe_fixes=True)
+            initial_result = ruff_tool.check([temp_file])
+            initial_count = initial_result.issues_count
+
+            # Apply fixes
+            fix_result = ruff_tool.fix([temp_file])
+            assert_that(fix_result.success).is_true()
+
+            # Check remaining issues
+            final_result = ruff_tool.check([temp_file])
+            final_count = final_result.issues_count
+
+            # Should have fewer issues after fixing
+            assert_that(final_count).is_less_than_or_equal_to(initial_count)
+
+        finally:
+            os.unlink(temp_file)
+
+    def test_sim_simplify_fixing(self, ruff_tool) -> None:
+        """Test SIM (flake8-simplify) rule fixing.
+
+        Args:
+            ruff_tool: RuffTool fixture instance.
+        """
+        import os
+        import tempfile
+
+        # Create a temporary file with SIM violations
+        content = """
+def test_function():
+    x = 5
+    # SIM101: Unnecessary if-else
+    if x > 0:
+        result = True
+    else:
+        result = False
+    return result
+"""
+
+        with tempfile.NamedTemporaryFile(mode="w", suffix=".py", delete=False) as f:
+            f.write(content)
+            f.flush()
+            temp_file = f.name
+
+        try:
+            # Check initial issues
+            ruff_tool.set_options(select=["SIM"], unsafe_fixes=True)
+            initial_result = ruff_tool.check([temp_file])
+            initial_count = initial_result.issues_count
+
+            # Apply fixes
+            fix_result = ruff_tool.fix([temp_file])
+            assert_that(fix_result.success).is_true()
+
+            # Check remaining issues
+            final_result = ruff_tool.check([temp_file])
+            final_count = final_result.issues_count
+
+            # Should have fewer issues after fixing
+            assert_that(final_count).is_less_than_or_equal_to(initial_count)
+
+        finally:
+            os.unlink(temp_file)
