@@ -1,3 +1,5 @@
+"""Tests for Black formatter table and output rendering."""
+
 from __future__ import annotations
 
 from assertpy import assert_that
@@ -9,7 +11,8 @@ from lintro.formatters.tools.black_formatter import (
 from lintro.parsers.black.black_issue import BlackIssue
 
 
-def test_black_table_descriptor_columns_and_rows():
+def test_black_table_descriptor_columns_and_rows() -> None:
+    """Ensure columns and rows render expected values for issues."""
     desc = BlackTableDescriptor()
     assert_that(desc.get_columns()).is_equal_to(["File", "Message"])
     issues = [
@@ -21,7 +24,8 @@ def test_black_table_descriptor_columns_and_rows():
     assert_that(rows[0][1]).contains("reformat")
 
 
-def test_format_black_issues_all_styles():
+def test_format_black_issues_all_styles() -> None:
+    """Ensure all styles return a non-empty string for issues list."""
     issues = [
         BlackIssue(file="a.py", message="Would reformat file"),
         BlackIssue(file="b.py", message="Reformatted file"),
@@ -32,7 +36,8 @@ def test_format_black_issues_all_styles():
         assert_that(len(out) > 0).is_true()
 
 
-def test_format_black_issues_empty():
+def test_format_black_issues_empty() -> None:
+    """Ensure empty issues still produce a valid string output."""
     out = format_black_issues(issues=[], format="grid")
     # Grid formatter returns an empty string when no rows
     assert_that(isinstance(out, str)).is_true()
