@@ -1,9 +1,12 @@
+"""Tests for Black parser utilities."""
+
 from __future__ import annotations
 
 from lintro.parsers.black.black_parser import parse_black_output
 
 
-def test_parse_black_output_would_reformat_single_file():
+def test_parse_black_output_would_reformat_single_file() -> None:
+    """Parse a single-file 'would reformat' message into one issue."""
     output = (
         "would reformat src/app.py\nAll done! 💥 💔 💥\n1 file would be reformatted."
     )
@@ -13,7 +16,8 @@ def test_parse_black_output_would_reformat_single_file():
     assert "Would reformat" in issues[0].message
 
 
-def test_parse_black_output_reformatted_multiple_files():
+def test_parse_black_output_reformatted_multiple_files() -> None:
+    """Parse multi-file 'reformatted' output into per-file issues."""
     output = (
         "reformatted a.py\nreformatted b.py\nAll done! ✨ 🍰 ✨\n2 files reformatted"
     )
@@ -23,7 +27,8 @@ def test_parse_black_output_reformatted_multiple_files():
     assert all("Reformatted" in i.message for i in issues)
 
 
-def test_parse_black_output_no_issues():
+def test_parse_black_output_no_issues() -> None:
+    """Return empty list when Black reports no issues."""
     output = "All done! ✨ 🍰 ✨\n1 file left unchanged."
     issues = parse_black_output(output)
     assert issues == []
