@@ -1,3 +1,5 @@
+"""Unit tests for custom exception hierarchy and messages."""
+
 from __future__ import annotations
 
 from assertpy import assert_that
@@ -9,7 +11,8 @@ from lintro.exceptions.errors import (
 )
 
 
-def test_custom_exceptions_str_and_inheritance():
+def test_custom_exceptions_str_and_inheritance() -> None:
+    """Ensure custom exceptions inherit and stringify as expected."""
     base = LintroError("base")
     assert_that(isinstance(base, Exception)).is_true()
     assert_that(str(base)).is_equal_to("base")
