@@ -11,7 +11,7 @@ from lintro.utils.tool_executor import _get_tools_to_run
 
 
 def test_fmt_excludes_bandit_by_default() -> None:
-    """fmt should include only tools that can_fix (Bandit excluded)."""
+    """Fmt should include only tools that can_fix (Bandit excluded)."""
     tools = _get_tools_to_run(tools=None, action="fmt")
     names = {t.name for t in tools}
     assert_that(names).does_not_contain("BANDIT")
