@@ -7,7 +7,8 @@ from assertpy import assert_that
 import lintro.utils.tool_utils as tu
 
 
-def test_format_as_table_fallback_when_no_tabulate():
+def test_format_as_table_fallback_when_no_tabulate() -> None:
+    """Fallback to plain text table when tabulate is unavailable."""
     # Force TABULATE_AVAILABLE False
     tu.TABULATE_AVAILABLE = False
     issues = [
@@ -22,9 +23,14 @@ def test_format_as_table_fallback_when_no_tabulate():
     ).is_true()
 
 
-def test_parse_tool_list_error_on_bad_name():
+def test_parse_tool_list_error_on_bad_name() -> None:
+    """Raise ValueError when parsing an unknown tool name.
+
+    Raises:
+        AssertionError: If the expected ValueError is not raised.
+    """
     try:
         _ = tu.parse_tool_list("notatool")
-        assert False, "Expected ValueError for bad tool name"
+        raise AssertionError("Expected ValueError for bad tool name")
     except ValueError as e:  # noqa: PT017
         assert_that("Unknown core" in str(e) or "Unknown tool" in str(e)).is_true()
